@@ -10,15 +10,20 @@
 
 #ifndef BiopolymerClass_H_
 #define BiopolymerClass_H_
+
+#include "MMB_config.h"
+
+#include "molmodel/internal/Compound.h"
 #define MUTATIONMINORSEPARATOR "-"
 #define MUTATIONMAJORSEPARATOR "."
 
 #include "Mutation.h"
 #include "SimTKmolmodel.h"
-#include <seqan/align.h>
 #include "BaseInteractionParameterReader.h"
 #include "ConstraintContainer.h"
-#include "ReferenceNeighborList.h"
+
+#include <openmm/reference/ReferenceNeighborList.h>
+#include <seqan/align.h>
 
 #include <string>
 #include <array>
@@ -213,8 +218,10 @@ public:
     Vec3        getAtomLocationInMobilizedBodyFrame(  ResidueID myResidueID,   String myAtomName); 
     const MobilizedBody & getAtomMobilizedBody(SimbodyMatterSubsystem & matter, const ResidueID &myResidueID, const String &myAtomName) const;
     MobilizedBody & updAtomMobilizedBody(SimbodyMatterSubsystem & matter,   ResidueID myResidueID,   String myAtomName);
+    MobilizedBody & updAtomMobilizedBody(SimbodyMatterSubsystem & matter, const Compound::AtomIndex aIx);
     MobilizedBodyIndex getAtomMobilizedBodyIndex( SimbodyMatterSubsystem & matter, const ResidueID &myResidueID, const String &myAtomName) const;
     Vec3        calcAtomLocationInGroundFrame(const  State & state, const ResidueID &residueID, const String &atomName);
+    Vec3        calcAtomLocationInGroundFrame(const State &state, Compound::AtomIndex aIx);
     Vec3        calcDefaultAtomLocationInGroundFrame(const ResidueID &residueID, const String &atomName) const;
     void        loadResidueIDVector();
     void        loadResidueIDVectorAscending(ResidueID firstResidueID);
@@ -241,10 +248,8 @@ public:
     MMBAtomInfo mmbAtomInfo(const ResidueID &myResidueID, const ResidueInfo::AtomIndex &myResidueInfoAtomIndex, SimbodyMatterSubsystem& matter) const;
     MMBAtomInfo mmbAtomInfo(const ResidueID &myResidueID, const ResidueInfo::AtomIndex &myResidueInfoAtomIndex, SimbodyMatterSubsystem& matter, DuMMForceFieldSubsystem & dumm) const;
     //MMBAtomInfo mmbAtomInfo(  ResidueID myResidueID,   ResidueInfo::AtomIndex myResidueInfoAtomIndex,  SimbodyMatterSubsystem& matter, DuMMForceFieldSubsystem & dumm , State & state);
-    #ifdef USE_OPENMM
     void        initializeAtomInfoVector(SimbodyMatterSubsystem & matter,  const vector<AtomicPropertyOverrideStruct>  & myAtomicPropertyOverrideVector);
     void        initializeAtomInfoVector(SimbodyMatterSubsystem & matter,DuMMForceFieldSubsystem & dumm, const vector<AtomicPropertyOverrideStruct> & atomicPropertyOverrideVector);
-    #endif
 
     vector<MMBAtomInfo> getAtomInfoVector();
     void printAtomInfoVector(){for (int i = 0 ; i < atomInfoVector.size(); i++) atomInfoVector[i].print(); };
@@ -288,13 +293,6 @@ public:
     ResidueID safeSum(ResidueID  inputResidueID, int  increment );
     ResidueID sum(ResidueID  oldResidueID, int  increment ) const;
      
-    #ifndef USE_OPENMM
-    /** 
-    * Get all residues within "distance" (nm) of location
-    * @return a vector of ResidueID
-    */ 
-    std::vector<ResidueID> getResiduesWithin(Vec3 location, double distance);
-    #endif
     //void writeDisulphideBridges(std::ofstream & output, SimbodyMatterSubsystem& matter );
 
 
@@ -316,7 +314,7 @@ public:
     template<class ResidueStretchType>
     void selectivelyRemoveResidueStretchFromContainer(const ResidueStretch & residueStretch, ResidueStretchContainer <ResidueStretchType> & residueStretchContainer);
 
-    TAlign    createGappedAlignment(BiopolymerClass otherBiopolymerClass,  double alignmentForcesGapPenalty = -1 );
+    //TAlign    createGappedAlignment(BiopolymerClass otherBiopolymerClass,  double alignmentForcesGapPenalty = -1, double matchScore = 0, double mismatchScore = -1 );
     int getCorrespondingMutationInCurrentBiopolymer(const BiopolymerClass &otherBiopolymerClass, TAlign align,Mutation mutationInOtherBiopolymer, Mutation & mutationInCurrentBiopolymer);
     int getCorrespondingResidueInCurrentBiopolymer(const BiopolymerClass &otherBiopolymerClass, TAlign align, ResidueID residueIdInOtherBiopolymerClass, ResidueID & correspondingResidueInOtherBiopolymerClass); 
     void sort( vector <ResidueID> & residueIDVector);
@@ -331,14 +329,14 @@ private :
     //map <const String, PdbStructure> pdbStructureMap;
 
 public:
-    #ifdef BuildNtC
+    #ifdef MMB_NTC_ENABLED
     std::vector<std::array<double, 361>> hist;
     std::vector<std::array<double, 361>> prob;
     std::vector<double> counter;
     std::vector<std::array<double, 31>> hist_d;
     std::vector<std::array<double, 31>> prob_d;
     std::vector<double> counter_d;
-    #endif
+    #endif // MMB_NTC_ENABLED
     int     count = 0;
 
     //BiopolymerClassContainer(){};
@@ -441,7 +439,6 @@ public:
     void        setSingleBondMobility(vector<SingleBondMobility>);  
     void        printAllIncludedResidues (const vector<IncludeAllNonBondAtomsInResidue> & includeAllNonBondAtomsInResidueVector);
 
-    #ifdef USE_OPENMM
     std::vector< std::pair<const BiopolymerClass, const ResidueID> > getResiduesWithin(const String & chainID, const ResidueID & resID, double radius, const State & state, OpenMM::NeighborList &  neighborList);
     std::vector< std::pair<const BiopolymerClass, const ResidueID> > getResiduesWithin(const String & chainID, const ResidueID & resID, double radius, OpenMM::NeighborList & neighborList);
     std::vector< std::pair<const BiopolymerClass, const ResidueID> > getResiduesWithin(vector<MMBAtomInfo>& concatenatedAtomInfoVector, const String & chainID, const ResidueID & resID, double radius, OpenMM::NeighborList & neighborList);
@@ -452,7 +449,6 @@ public:
     // Template functions have to be defined in the same compilation unit in which it is used, under many circumstances. Hence the following pass-through or wrapper function:
     vector<SingleResidue>  findBiopolymerResiduesWithinRadius  (const  vector<MobilizerWithin> & allResiduesWithinVector,  const State state);
     void        includeAllResiduesWithin (const vector<AllResiduesWithin> & includeAllResiduesWithinVector,    vector<IncludeAllNonBondAtomsInResidue> & includeAllNonBondAtomsInResidueVector, const State state);
-    #endif
 
     void        includeAllNonBondAtomsInResidues(vector<IncludeAllNonBondAtomsInResidue>  myIncludeAllNonBondAtomsInResidueVector, State & state, DuMMForceFieldSubsystem & dumm) ;
     void        includeNonBondAtoms(  vector<IncludeNonBondAtomInBiopolymerStruct> includeNonBondAtomInBiopolymerVector,  State & state, DuMMForceFieldSubsystem & dumm) ;
@@ -542,10 +538,8 @@ public:
     void        deleteResidue(Mutation myDeletion,   bool proteinCapping);
     void        setMutationVectorFromString (const std::string mutationString);
     void        addIntraChainInterfaceResidues(String chain, vector<IncludeAllNonBondAtomsInResidue> & myIncludeAllNonBondAtomsInResidueVector , double radius, SimbodyMatterSubsystem & matter,State & state);
-    #ifdef USE_OPENMM
     void        createDisulphideBridges(std::ofstream & output);
     void        createDisulphideBridges();
-    #endif
     void        loadCysteineAtomInfoVector(vector <MMBAtomInfo> & cysteineAtomInfoVector ) ;
     vector<Mutation> getCompositeMutationVector() {return          mutationVector;}
 
