@@ -1,3 +1,4 @@
+// vim: set sw=4 ts=4 sts=4 expandtab :
 /* -------------------------------------------------------------------------- *
  *                           MMB (MacroMoleculeBuilder)                       *
  * -------------------------------------------------------------------------- *
@@ -21,25 +22,16 @@
 #include "SimTKsimbody.h"
 #include "SimTKmolmodel.h"
 #include "MMBLogger.h"
-#include "RealVec.h"
-#include "ReferenceNeighborList.h"
+#include <openmm/reference/RealVec.h>
+#include <openmm/reference/ReferenceNeighborList.h>
 #include <seqan/align.h>
-#ifdef Lepton_USAGE // This is included only if Lepton_USAGE is defined
+#ifdef LEPTON_ENABLED
 #include "Lepton.h"
 #endif
 
+typedef OpenMM::Vec3 openmmVecType ;
 
-#ifdef USE_OPENMM_REALVEC
-#ifdef WARN_OPENMM_REALVEC
-    #pragma message ("using OpenMM::RealVec: USE_OPENMM_REALVEC defined")
-#endif // WARN_OPENMM_REALVEC
-typedef OpenMM::RealVec openmmVecType ;
-#else 
-#ifdef WARN_OPENMM_REALVEC
-    #pragma message ("using OpenMM::Vec3: USE_OPENMM_REALVEC NOT defined")
-#endif // WARN_OPENMM_REALVEC
-typedef OpenMM::Vec3    openmmVecType ;
-#endif
+class BiopolymerClass;
 
 using namespace SimTK;
 using namespace std;  
@@ -90,9 +82,17 @@ public:
     void validateExists();
     //void validateReadable();
 };
-int myMkdir(const std::string & directoryPath);
 
-int myChdir(const std::string & directoryPath);
+int MMB_EXPORT myMkdir(const std::string & directoryPath);
+int MMB_EXPORT myChdir(const std::string & directoryPath);
+
+enum class CopyFileResult {
+    Success,
+    Io_Error,
+    No_Space,
+};
+
+CopyFileResult MMB_EXPORT mmbCopyFile(const std::string &sourceFileName, const std::string &destinationFileName);
 
 void MMB_EXPORT closingMessage() ;
 
@@ -107,8 +107,10 @@ int   myAtoI(  map<const String,double> myUserVariables,  const char* value);
 // a recursive algorithm for reading a double from a String.  This String may contain ints, user variables (begin with @), +, and -.  No whitespaces or additional characters should be in the String.
 inline double   myAtoF(  map<const String,double> myUserVariables,  const char* value){
     MMBLOG_FILE_FUNC_LINE(INFO, "inside myAtoF. converting string : >"<<value<<"<"<<endl);
+#ifdef LEPTON_ENABLED
 
-#ifdef Lepton_USAGE
+//#ifdef Lepton_USAGE
+    MMBLOG_FILE_FUNC_LINE(DEBUG, " Using Lepton : "<<endl);
     map<string,double> leptonFormatUserVariables; // Wish this were not necessary. but userVariables uses the signature const SimTK::String,double . Lepton uses string, double.
     leptonFormatUserVariables.clear();
     for (auto  myUserVariablesIterator = myUserVariables.begin() ; myUserVariablesIterator !=myUserVariables.end(); myUserVariablesIterator++) {
@@ -118,7 +120,8 @@ inline double   myAtoF(  map<const String,double> myUserVariables,  const char*
     MMBLOG_FILE_FUNC_LINE(INFO, " Lepton evaluation = >"<< leptonResult<<"< "<<std::endl);
     return leptonResult; // if Lepton_USAGE is defined, then we return here and the rest of the procedure is not used. 
 #endif
-    // If Lepton_USAGE is NOT defined, then we parse the formula the old dumb way, as follows.
+    // If  LEPTON_ENABLED is NOT defined, then we parse the formula the old dumb way, as follows.
+    MMBLOG_FILE_FUNC_LINE(DEBUG, " NOT using Lepton : "<<endl);
 
     size_t plusPosition  = String(value).find_last_of('+'); // returns the position of the last '+' in value
     size_t minusPosition = String(value).find_last_of('-'); // ditto for '-'
@@ -273,7 +276,7 @@ std::string   trim(const std::string& str,
 }
 */
 
-bool vectorCompare(String myString, vector<String> & comparisonStringVector) ;
+bool MMB_EXPORT vectorCompare(String myString, vector<String> & comparisonStringVector) ;
 
 
 
@@ -613,7 +616,16 @@ class     NTC_Classes {
                double weight,weight2;
                int    meta = 0;
                int    count = 0;
+               BiopolymerClass *bp;
+               std::array<Compound::AtomIndex, 4> atomIndices;
+
     void print(){
+        std::stringstream ss{};
+        for (const auto &i : atomIndices) {
+            ss << i << ", ";
+        }
+        ss << std::endl;
+
         MMBLOG_PLAIN(INFO, " Printing parameters for NtC:"<<std::endl
         << " NtC_FirstBPChain = >"<<NtC_FirstBPChain<<"<"<<std::endl
         << " FirstBPResidue = >"<<FirstBPResidue.outString()<<"<"<<std::endl
@@ -628,7 +640,8 @@ class     NTC_Classes {
         << " NTC_PAR_BondRowIndex = >"<<NTC_PAR_BondRowIndex<<"<"<<std::endl
         << " meta = >"<<meta<<"<"<<std::endl
         << " count = >"<<count<<"<"<<std::endl
-	<< std::endl);
+        << " Molmodel atom indices" << ss.str() << std::endl
+        << std::endl);
     }
                
 };
@@ -1149,22 +1162,24 @@ struct AtomSpring {
                 <<" groundLocation: "<< groundLocation           <<std::endl
                 <<""<<std::endl);
        }*/
+       // Note that this works only with loggingSeverity DEBUG:
        void print(){//enum MMBLogger::Severity severity = MMBLogger::Severity::INFO){
-            MMBLOG_FILE_LINE(INFO, " Printing AtomSpring  contents:"<<std::endl
-                <<" atom1Chain    : "<<atom1Chain                <<std::endl  
-                <<" atom2Chain    : "<<atom2Chain                <<std::endl  
-                <<" atom1Residue  : "<<atom1Residue.outString()  <<std::endl  
-                <<" atom2Residue  : "<<atom2Residue.outString()  <<std::endl  
-                <<" atom1Name     : "<<atom1Name                 <<std::endl  
-                <<" atom2Name     : "<<atom2Name                 <<std::endl  
-                <<" toGround      : "<< toGround                 <<std::endl     
-                <<" tether        : "<< tether                   <<std::endl
-                <<" deadLength    : "<< deadLength               <<std::endl
-                <<" deadLengthIsFractionOfInitialLength : "<< deadLengthIsFractionOfInitialLength  <<std::endl
-                <<" deadLengthFraction : "<< deadLengthFraction  <<std::endl
-                <<" groundLocationIsRelativeToAtom1Location : "<< groundLocationIsRelativeToAtom1Location <<std::endl
-                <<" groundLocation: "<< groundLocation           <<std::endl
-                <<" forceConstant : "<< forceConstant            <<std::endl
+	       
+            MMBLOG_FILE_LINE(DEBUG, " Printing AtomSpring  contents:"<<std::endl
+                <<" atom1Chain    : "<<atom1Chain                  
+                <<" atom2Chain    : "<<atom2Chain                  
+                <<" atom1Residue  : "<<atom1Residue.outString()    
+                <<" atom2Residue  : "<<atom2Residue.outString()    
+                <<" atom1Name     : "<<atom1Name                   
+                <<" atom2Name     : "<<atom2Name                   
+                <<" toGround      : "<< toGround                      
+                <<" tether        : "<< tether                   
+                <<" deadLength    : "<< deadLength               
+                <<" deadLengthIsFractionOfInitialLength : "<< deadLengthIsFractionOfInitialLength  
+                <<" deadLengthFraction : "<< deadLengthFraction  
+                <<" groundLocationIsRelativeToAtom1Location : "<< groundLocationIsRelativeToAtom1Location 
+                <<" groundLocation: "<< groundLocation           
+                <<" forceConstant : "<< forceConstant            
                 <<""<<std::endl);
        } 
        /*
@@ -1183,6 +1198,26 @@ struct AtomSpring {
                 <<" groundLocation: "<< groundLocation           <<std::endl
                 <<""<<std::endl);
        }*/
+
+
+       void initialize(){
+	    MMBLOG_FILE_FUNC_LINE(DEBUG, " initializing atomSpring  "<<endl);
+            atom1Name = "XXXX"           ;   
+            atom2Name = "XXXX"           ;   
+            atom1Residue =  ResidueID(-1111, ' ')        ;   
+            atom2Residue =  ResidueID(-1111, ' ')        ;   
+            atom1Chain = "XXXX";
+            atom2Chain = "XXXX";
+            toGround   = false;
+            tether     = false;
+	    groundLocationIsRelativeToAtom1Location = false;
+            groundLocation = Vec3(0);
+            forceConstant  = 0.0 ;
+            deadLength     = 0.0 ; 
+            deadLengthFraction     = 0.0 ; 
+	    forceConstant  = 129790.8 ; // base the default value on the spring constant of a carbon-carbon single bond
+	    print(); // Only acts if loggingSeverity DEBUG
+       }
        AtomSpring(String chain1, ResidueID res1, String name1,
                   String chain2, ResidueID res2, String name2,
                   double constant,
@@ -1213,7 +1248,8 @@ struct AtomSpring {
 
        AtomSpring()
        {
-            atom1Name = "XXXX"           ;   
+	    initialize();
+            /*atom1Name = "XXXX"           ;   
             atom2Name = "XXXX"           ;   
             atom1Residue =  ResidueID(-1111, ' ')        ;   
             atom2Residue =  ResidueID(-1111, ' ')        ;   
@@ -1225,7 +1261,7 @@ struct AtomSpring {
             groundLocation = Vec3(0);
             forceConstant  = 0.0 ;
             deadLength     = 0.0 ; 
-            deadLengthFraction     = 0.0 ; 
+            deadLengthFraction     = 0.0 ; */
        }
 };
 
@@ -1243,224 +1279,6 @@ struct WaterDropletAboutResidueStruct {
     double radius;
     double tetherStrength;
 };
-/*
-class BiopolymerClass;
-String BiopolymerClass::getChainID();
-String BiopolymerClass::getSubSequence(ResidueID, ResidueID );
-ResidueID BiopolymerClass::sum (ResidueID, int);
-vector<ResidueID> BiopolymerClass::sort(vector<ResidueID>);
-String BiopolymerClass::getSequence(vector<ResidueID>);
-const   ResidueInfo::Index BiopolymerClass::getResidueIndex(ResidueID);
-class MMB_EXPORT  BiopolymerClass {
-public:
-    String getChainID();
-    String getSubSequence(ResidueID, ResidueID );
-    ResidueID sum (ResidueID, int);
-    vector<ResidueID> sort(vector<ResidueID>);
-    String getSequence(vector<ResidueID>);
-    const   ResidueInfo::Index getResidueIndex(ResidueID);
-};
-*/
-/*
-typedef char TChar;                             // character type
-typedef seqan::String<TChar> TSequence;                // sequence type
-typedef seqan::Align<TSequence, seqan::ArrayGaps> TAlign;  
-
-struct ThreadingPartner {
-    BiopolymerClass * biopolymerClass;
-    vector <ResidueID> includedResidues;
-    ResidueID startResidue;
-    ResidueID endResidue;
-    TSequence sequence;
-};
-class ThreadingStruct {
-   private:
-       ThreadingPartner threadingPartners[2];
-       seqan::AlignmentStats alignmentStats;
-       TAlign align;
-       bool alignHasBeenComputed;
-    public:
-        // This method is not needed. just use updThreadingPartner.
-        //void setThreadingPartner (ThreadingPartner myThreadingPartner, int index){threadingPartners[index] =  myThreadingPartner;}
-        ThreadingPartner & updThreadingPartner (int index){return threadingPartners[index];}
-        std::string getChain(int index){return threadingPartners[index].biopolymerClass->getChainID();};
-        double forceConstant;
-        bool backboneOnly;
-        bool isGapped; //if False, then alignment is being provided explicitly. if True, precise alignment will be determined by MMB/SeqAn
-        bool deadLengthIsFractionOfInitialLength; //If True, then dead length of each spring will be set to deadLengthFraction * <initial spring extension>. It makes sense that 1 > deadLengthFraction > 0.
-        double deadLengthFraction;
-        seqan::AlignmentStats getAlignmentStats(){return alignmentStats;}
-        void   setAlignmentStats(seqan::AlignmentStats myAlignmentStats){ alignmentStats = myAlignmentStats;}
-
-        // align, alignmentStats should be empty, undefined, or garbage unless and until this method is called:
-        void setLongSequences(){
-            threadingPartners[0].sequence = threadingPartners[0].biopolymerClass->getSubSequence(threadingPartners[0].startResidue , threadingPartners[0].endResidue );
-            threadingPartners[1].sequence = threadingPartners[1].biopolymerClass->getSubSequence(threadingPartners[1].startResidue , threadingPartners[1].endResidue );
-            computeAlign(); // Just to make sure align is in sync with the new sequences
-        }
-
-        void sortIncludedResidues(){
-            threadingPartners[0].includedResidues = threadingPartners[0].biopolymerClass->sort(threadingPartners[0].includedResidues);
-            threadingPartners[1].includedResidues = threadingPartners[1].biopolymerClass->sort(threadingPartners[1].includedResidues);
-        }
-    bool hasResidue( ResidueID residue , int biopolymerIndex ){
-        for (int i = 0; i < threadingPartners[biopolymerIndex].includedResidues.size() ;  i++){
-            if  (  threadingPartners[biopolymerIndex].includedResidues[i] == residue) return 1;
-        }
-        return 0;
-    }
-
-    void supplementIncludedResidues(int fromBiopolymer, int toBiopolymer){
-	for (int i = 0; i < threadingPartners[fromBiopolymer].includedResidues.size() ;  i++){
-	    ResidueID correspondingResidue;
-	    if (!( getCorrespondingResidue(threadingPartners[fromBiopolymer].includedResidues[i], correspondingResidue, fromBiopolymer, toBiopolymer) )) // returns 0 if successful
-	    {
-		if (!(hasResidue(  correspondingResidue , toBiopolymer ) )){
-		    threadingPartners[toBiopolymer].includedResidues.push_back(correspondingResidue);
-		}  // of if
-	    } // of if
-	}  // of for
-    } // of method
-
-    void supplementIncludedResidues(){
-	supplementIncludedResidues(0,1);
-	supplementIncludedResidues(1,0);
-    } // of method
-
-    void setShortSequences(){
-	sortIncludedResidues();
-	threadingPartners[0].sequence = threadingPartners[0].biopolymerClass->getSequence(threadingPartners[0].includedResidues);
-	threadingPartners[1].sequence = threadingPartners[1].biopolymerClass->getSequence(threadingPartners[1].includedResidues);
-	computeAlign(); // Just to make sure align is in sync with the new sequences
-    }
-
-     void computeAlign(){
-	seqan::resize(rows(align), 2);
-	assignSource(row(align,0),threadingPartners[0].sequence);
-	assignSource(row(align,1),threadingPartners[1].sequence);
-	seqan::Blosum62 scoringScheme(-1, -12);
-	int score = globalAlignment(align,scoringScheme ); // ..signature:Score<TValue, Simple>(match, mismatch, gap [, gap_open])
-	//"62" means matrix was constructed with max 62% seq. identity alignment.
-	std::cout <<__FILE__<<":"<<__LINE__<< "Score: " << score << ::std::endl;
-	std::cout <<__FILE__<<":"<<__LINE__<< align << ::std::endl;
-	computeAlignmentStats(alignmentStats, align, scoringScheme);
-	printAlignmentStats();
-	alignHasBeenComputed = 1;
-    }
-
-    // return 0 for success, 1 for failure
-    bool getCorrespondingResidue(const ResidueID queryResidue, ResidueID & correspondingResidue, const int queryBiopolymerIndex, const int correspondingBiopolymerIndex){
-	if (!( queryBiopolymerIndex ^ correspondingBiopolymerIndex )){std::cout <<__FILE__<<":"<<__LINE__<< " queryBiopolymerIndex and  correspondingBiopolymerIndex must be set to 0,1 or 1,0. You have   "<< queryBiopolymerIndex <<" , " << correspondingBiopolymerIndex <<std::endl; exit(1);}
-	if (( queryBiopolymerIndex > 1) ||  ( queryBiopolymerIndex < 0) ){std::cout <<__FILE__<<":"<<__LINE__<< " queryBiopolymerIndex =  "<< queryBiopolymerIndex <<" is out of range. Expected 0 or 1. "  <<std::endl; exit(1);}
-	if (( correspondingBiopolymerIndex > 1) ||  ( correspondingBiopolymerIndex < 0) ){std::cout <<__FILE__<<":"<<__LINE__<< " correspondingBiopolymerIndex =  "<< correspondingBiopolymerIndex <<" is out of range. Expected 0 or 1. "  <<std::endl; exit(1);}
-	if (!(alignHasBeenComputed)) {std::cout <<__FILE__<<":"<<__LINE__<< " alignHasBeenComputed = "<< alignHasBeenComputed <<std::endl; exit(1);}
-	int querySourceIndex = threadingPartners[queryBiopolymerIndex].biopolymerClass->getResidueIndex(queryResidue) -  threadingPartners[queryBiopolymerIndex].biopolymerClass->getResidueIndex(threadingPartners[queryBiopolymerIndex].startResidue);
-	 int viewIndex = toViewPosition(row(align, queryBiopolymerIndex),querySourceIndex);
-	 int correspondingSourceIndex =  toSourcePosition(row(align,correspondingBiopolymerIndex ) ,viewIndex);
-	 if (String(seqan::row (align,correspondingBiopolymerIndex )[viewIndex]) == ("-")   ){
-	     std::cout <<__FILE__<<":"<<__LINE__<< " queryResidue = "<<queryResidue.outString()<< " of queryBiopolymerIndex "<<queryBiopolymerIndex<< " with chain ID "<<   threadingPartners[queryBiopolymerIndex].biopolymerClass->getChainID() << " is an insertion with respect to correspondingBiopolymerIndex. Unable to set correspondingResidue "  <<std::endl;
-	     return 1;
-	 }
-	 correspondingResidue =  threadingPartners[correspondingBiopolymerIndex].biopolymerClass->sum( threadingPartners[correspondingBiopolymerIndex].startResidue, correspondingSourceIndex);
-	 return 0;
-     }; // of method
-
-     const void printAlignmentStats(){
-         std::cout<<__FILE__<<":"<<__LINE__<<std::endl;
-         std::cout << align
-               << "score:               " << alignmentStats.alignmentScore << "\n"
-               << "gap opens:           " << alignmentStats.numGapOpens << "\n"
-               << "gap extensions:      " << alignmentStats.numGapExtensions << "\n"
-               << "num insertions:      " << alignmentStats.numInsertions << "\n"
-               << "num deletions:       " << alignmentStats.numDeletions << "\n"
-               << "num matches:         " << alignmentStats.numMatches << "\n"
-               << "num mismatches:      " << alignmentStats.numMismatches << "\n"
-               << "num positive scores: " << alignmentStats.numPositiveScores << "\n"
-               << "num negative scores: " << alignmentStats.numNegativeScores << "\n"
-               << "percent similarity:  " << alignmentStats.alignmentSimilarity << "\n"
-               << "percent identity:    " << alignmentStats.alignmentIdentity << "\n\n\n";
-         std::cout<<__FILE__<<":"<<__LINE__<<std::endl;
-     }
-
-
-    ThreadingStruct(BiopolymerClass * biopolymerClass0, ResidueID resStart0, ResidueID resEnd0,
-                 BiopolymerClass * biopolymerClass1, ResidueID resStart1, ResidueID resEnd1,
-                 double forceConstant, bool backboneOnly
-                 ) //:
-
-        //residueStart0(resStart0), residueEnd0(resEnd0),
-                     //residueStart1(resStart1), residueEnd1(resEnd1),
-                     //forceConstant(forceConstant), backboneOnly(backboneOnly)
-        {   
-            updThreadingPartner(0).biopolymerClass = biopolymerClass0; 
-            updThreadingPartner(1).biopolymerClass = biopolymerClass1; 
-            updThreadingPartner(0).includedResidues.clear();
-            //chain1ResiduesIncluded.clear(); 
-            alignHasBeenComputed = 0; 
-            threadingPartners[0].sequence = ""; threadingPartners[1].sequence = "";}
-
-            // This constructor has to change because we are getting rido of chainID's. Also, usage in MMB has to change.
-     ThreadingStruct() 
-                         {
-                         alignHasBeenComputed = 0;
-                         threadingPartners[0].includedResidues.clear(); threadingPartners[1].includedResidues.clear();
-                         threadingPartners[0].sequence = ""; threadingPartners[1].sequence = "";}
-}; // of class
-*/
-
-
-/*
-class ThreadingStructOld {
-  private:
-    seqan::AlignmentStats alignmentStats;
-    vector <ResidueID> chain1ResiduesIncluded;
-  public:
-    String chainID1;
-    ResidueID residueStart1;
-    ResidueID residueEnd1;
-    String chainID2;
-    ResidueID residueStart2;
-    ResidueID residueEnd2;
-    double forceConstant;
-    bool backboneOnly;
-    bool isGapped; //if False, then alignment is being provided explicitly. if True, precise alignment will be determined by MMB/SeqAn
-    bool deadLengthIsFractionOfInitialLength; //If True, then dead length of each spring will be set to deadLengthFraction * <initial spring extension>. It makes sense that 1 > deadLengthFraction > 0.
-    double deadLengthFraction;
-    double gapPenalty;
-    seqan::AlignmentStats getAlignmentStats(){return alignmentStats;}
-    void   setAlignmentStats(seqan::AlignmentStats myAlignmentStats){ alignmentStats = myAlignmentStats;}
-    const void printAlignmentStats(){
-        std::cout<<__FILE__<<":"<<__LINE__<<std::endl;
-        std::cout << align
-              << "score:               " << alignmentStats.alignmentScore << "\n"
-              << "gap opens:           " << alignmentStats.numGapOpens << "\n"
-              << "gap extensions:      " << alignmentStats.numGapExtensions << "\n"
-              << "num insertions:      " << alignmentStats.numInsertions << "\n"
-              << "num deletions:       " << alignmentStats.numDeletions << "\n"
-              << "num matches:         " << alignmentStats.numMatches << "\n"
-              << "num mismatches:      " << alignmentStats.numMismatches << "\n"
-              << "num positive scores: " << alignmentStats.numPositiveScores << "\n"
-              << "num negative scores: " << alignmentStats.numNegativeScores << "\n"
-              << "percent similarity:  " << alignmentStats.alignmentSimilarity << "\n"
-              << "percent identity:    " << alignmentStats.alignmentIdentity << "\n\n\n";    
-        std::cout<<__FILE__<<":"<<__LINE__<<std::endl;
-    }
-
-    ThreadingStructOld(String chain1, ResidueID resStart1, ResidueID resEnd1,
-                    String chain2, ResidueID resStart2, ResidueID resEnd2,
-                    double forceConstant, bool backboneOnly
-                    ) :
-                    chainID1(chain1), residueStart1(resStart1), residueEnd1(resEnd1),
-                    chainID2(chain2), residueStart2(resStart2), residueEnd2(resEnd2),
-                    forceConstant(forceConstant), backboneOnly(backboneOnly)
-    {   chain1ResiduesIncluded.clear();            
-    }
-
-    ThreadingStructOld() : chainID1(" "), residueStart1(ResidueID()), residueEnd1(ResidueID()),
-                        chainID2(" "), residueStart2(ResidueID()), residueEnd2(ResidueID()),
-                        forceConstant(0.0), backboneOnly(false)
-                        {chain1ResiduesIncluded.clear(); }
-};*/
 
 class MMBAtomInfo {
     public:
@@ -1560,9 +1378,7 @@ class InterfaceContainer    {
                         myInterface.Chains.clear(); myInterface.PartnerChains.clear();
             for (int i = 0; i < myChains.size(); i++) {myInterface.Chains.push_back( myChains[i]);}  myInterface.Depth = myDepth; myInterface.MobilizerString = myMobilizerString; interfaceVector.push_back(myInterface); };
         void addInterface(vector<String> myChains,vector<String> partnerChains,  double myDepth ,  String myMobilizerString = "NONE");
-        #ifdef USE_OPENMM
         vector<TwoAtomClass> retrieveCloseContactPairs(vector<MMBAtomInfo> & concatenatedAtomInfoVector );
-        #endif
         Interface getInterface(int interfaceIndex) {return  interfaceVector[interfaceIndex];};
         int numInterfaces() {return interfaceVector.size();};
         void print(){
