@@ -1,3 +1,4 @@
+// vim: set sw=4 ts=4 sts=4 expandtab :
 /* -------------------------------------------------------------------------- *
  *                           MMB (MacroMoleculeBuilder)                       *
  * -------------------------------------------------------------------------- *
@@ -9,16 +10,38 @@
  * -------------------------------------------------------------------------- */
 
 #include "Utils.h"
+#include <MMBLogger.h>
 
-//#include <boost/lexical_cast.hpp>
+#include <cstring>
+#include <functional>
+#include <iostream>
+#include <sstream>
+
+#ifdef LEPTON_ENABLED
+#include <Lepton.h>
+#endif
 
 #ifdef _WINDOWS
 #include <windows.h>
 #include <memory>
-#ifdef Lepton_USAGE // This is included only if Lepton_USAGE is defined
-#include "Lepton.h"
-#endif
+#else
+    #include <fcntl.h>
+    #include <sys/utsname.h>
+    #ifdef HAVE_COPY_FILE_RANGE
+        #ifndef _GNU_SOURCE
+            #define _GNU_SOURCE
+        #endif // _GNU_SOURCE
+        #include <unistd.h>
+    #endif // HAVE_COPY_FILE_RANGE
+    #ifdef HAVE_SENDFILE
+        #include <sys/sendfile.h>
+    #endif // HAVE_SENDFILE
+#endif // _WINDOWS
 
+using namespace std;
+using namespace SimTK;
+
+#ifdef _WINDOWS
 
 class SecurityDescriptorWrapper {
 public:
@@ -37,6 +60,28 @@ private:
     std::unique_ptr<char *> m_buffer;
 };
 
+inline
+std::string getErrorString(DWORD error) {
+	LPSTR buf = nullptr;
+
+    if (FormatMessageA(
+            FORMAT_MESSAGE_ALLOCATE_BUFFER | FORMAT_MESSAGE_FROM_SYSTEM | FORMAT_MESSAGE_IGNORE_INSERTS,
+		    NULL,
+            error,
+            MAKELANGID(LANG_NEUTRAL, SUBLANG_NEUTRAL),
+            (LPSTR)&buf,
+            0,
+            nullptr
+	    ) == 0) {
+        return "Unknown error";
+    }
+
+    std::string msg(buf);
+    LocalFree(buf);
+
+    return msg;
+}
+
 inline
 bool hasAccessRight(LPCSTR path, DWORD genericAccessRights) {
     SECURITY_DESCRIPTOR secDesc;
@@ -94,13 +139,53 @@ bool hasWriteAccess(LPCSTR path) {
     return hasAccessRight(path, GENERIC_READ | GENERIC_WRITE);
 }
 
+inline
+std::wstring multibyteToWideString(const std::string &str) {
+    auto ret = MultiByteToWideChar(
+        CP_UTF8,
+        MB_ERR_INVALID_CHARS,
+        str.c_str(),
+        -1,
+        NULL,
+        0
+    );
+
+    if (ret < 1) {
+        throw new std::runtime_error("Cannot calculate size of the array for widechar string");
+    }
+
+    auto buf = std::make_unique<WCHAR[]>(ret);
+
+    ret = MultiByteToWideChar(
+        CP_UTF8,
+        MB_ERR_INVALID_CHARS,
+        str.c_str(),
+        -1,
+        buf.get(),
+        ret
+    );
+
+    if (ret < 1) {
+        throw new std::runtime_error("Cannot convert to widechar string");
+    }
+
+    return std::wstring(buf.get());
+}
+
+inline
+std::wstring unicodeFullPath(const std::string &path) {
+    auto wpath = multibyteToWideString(path);
+
+    auto buf = std::make_unique<WCHAR[]>(32768);
+    if (GetFullPathNameW(wpath.c_str(), 32768, buf.get(), nullptr) == 0) {
+        throw new std::runtime_error("Cannot get full path name");
+    }
+
+    return std::wstring(buf.get());
+}
+
 #endif // _WINDOWS
 
-#include  <sstream> 
-using namespace std;
-using namespace SimTK;
-
-
 int myMkdir(const std::string & directoryPath) {
 #ifdef _WINDOWS
     MMBLOG_FILE_FUNC_LINE(INFO, " You are asking to create the directory  " << directoryPath << std::endl);
@@ -167,6 +252,377 @@ int myChdir(const std::string & directoryPath) {
 #endif // _WINDOWS
 }
 
+/* Copy file function variants */
+#ifdef _WINDOWS
+
+static const std::wstring LONG_PATH_LIMIT_PREFIX = L"\\\\?\\";
+CopyFileResult mmbCopyFile(const std::string &sourceFileName, const std::string &destinationFileName) {
+    try {
+        auto src = LONG_PATH_LIMIT_PREFIX + unicodeFullPath(sourceFileName);
+        auto dst = LONG_PATH_LIMIT_PREFIX + unicodeFullPath(destinationFileName);
+
+        if (!CopyFileW(src.c_str(), dst.c_str(), FALSE)) {
+            auto err = GetLastError();
+            if (err == ERROR_DISK_FULL) {
+                return CopyFileResult::No_Space;
+            }
+            MMBLOG_PLAIN(WARNING, "IO error while copying a file: " << getErrorString(err) << "\n");
+            return CopyFileResult::Io_Error;
+        }
+        return CopyFileResult::Success;
+    } catch (const std::runtime_error &ex) {
+        MMBLOG_PLAIN(WARNING, ex.what() << "\n");
+        return CopyFileResult::Io_Error;
+    }
+}
+
+#else
+
+inline
+auto getFileSizeFromFd(int fd) {
+    struct stat st;
+
+    int ret = fstat(fd, &st);
+    if (ret == -1) {
+        return -1L;
+    }
+
+    return st.st_size;
+}
+
+#ifdef HAVE_COPY_FILE_RANGE
+
+inline
+CopyFileResult mmbCopyFile_copy_file_range(const std::string &sourceFileName, const std::string &destinationFileName) {
+    int in = open(sourceFileName.c_str(), O_RDONLY);
+    if (in == -1) {
+        MMBLOG_PLAIN(WARNING, "Cannot open file " << sourceFileName << " for reading");
+
+        return CopyFileResult::Io_Error;
+    }
+
+    const auto srcSize = getFileSizeFromFd(in);
+    if (srcSize == -1) {
+        MMBLOG_PLAIN(WARNING, "Cannot determine size of the file to copy:" << strerror(errno));
+        close(in);
+
+        return CopyFileResult::Io_Error;
+    }
+
+    int out = creat(destinationFileName.c_str(), S_IWUSR | S_IRUSR);
+    if (out == -1) {
+        MMBLOG_PLAIN(WARNING, "Cannot open file " << destinationFileName << " for writing");
+	    close(in);
+
+        return CopyFileResult::Io_Error;
+    }
+
+    CopyFileResult retCode = CopyFileResult::Success;
+    auto bytesToCopy = srcSize;
+    while (bytesToCopy > 0) {
+        auto ret = copy_file_range(in, nullptr, out, nullptr, bytesToCopy, 0);
+        if (ret == -1) {
+            if (errno == ENOSPC || errno == EDQUOT) {
+                retCode = CopyFileResult::No_Space;
+            } else {
+                MMBLOG_PLAIN(WARNING, "IO error while copying a file: " << strerror(errno));
+
+                retCode = CopyFileResult::Io_Error;
+            }
+            goto out;
+        }
+
+        bytesToCopy -= ret;
+    }
+
+out:
+    close(in);
+    close(out);
+
+    return retCode;
+}
+
+#endif // HAVE_COPY_FILE_RANGE
+
+inline
+CopyFileResult mmbCopyFile_direct(const std::string &sourceFileName, const std::string &destinationFileName) {
+    const size_t BUFSIZE = 8 * 1024;
+    auto buf = std::make_unique<char[]>(BUFSIZE);
+
+    int in = open(sourceFileName.c_str(), O_RDONLY);
+    if (in == -1) {
+        MMBLOG_PLAIN(WARNING, "Cannot open file " << sourceFileName << " for reading");
+
+        return CopyFileResult::Io_Error;
+    }
+
+    const auto srcSize = getFileSizeFromFd(in);
+    if (srcSize == -1) {
+        MMBLOG_PLAIN(WARNING, "Cannot determine size of the file to copy:" << strerror(errno));
+        close(in);
+
+        return CopyFileResult::Io_Error;
+    }
+
+    int out = creat(destinationFileName.c_str(), S_IWUSR | S_IRUSR);
+    if (out == -1) {
+        MMBLOG_PLAIN(WARNING, "Cannot open file " << destinationFileName << " for writing");
+	    close(in);
+
+        return CopyFileResult::Io_Error;
+    }
+
+    CopyFileResult retCode = CopyFileResult::Success;
+    auto bytesToCopy = srcSize;
+    while (bytesToCopy > 0) {
+        auto blkBytesToCopy = read(in, buf.get(), BUFSIZE);
+        if (blkBytesToCopy == -1) {
+            MMBLOG_PLAIN(WARNING, "IO read error while copying a file: " << strerror(errno));
+
+            goto out;
+        }
+
+        while (blkBytesToCopy > 0) {
+            auto ret = write(out, buf.get(), blkBytesToCopy);
+            if (ret == -1) {
+                if (errno == ENOSPC || errno == EDQUOT) {
+                    retCode = CopyFileResult::No_Space;
+                } else {
+                    MMBLOG_PLAIN(WARNING, "IO write error while copying a file: " << strerror(errno));
+
+                    retCode = CopyFileResult::Io_Error;
+                }
+
+                goto out;
+            }
+
+            blkBytesToCopy -= ret;
+            bytesToCopy -= ret;
+        }
+    }
+
+    if (fsync(out) == -1) {
+        if (errno == ENOSPC || errno == EDQUOT) {
+            retCode = CopyFileResult::No_Space;
+        } else {
+            MMBLOG_PLAIN(WARNING, "IO write error while copying a file: " << strerror(errno));
+
+            retCode = CopyFileResult::Io_Error;
+        }
+    }
+
+out:
+    close(in);
+    close(out);
+
+    return retCode;
+}
+
+#ifdef HAVE_SENDFILE
+
+inline
+CopyFileResult mmbCopyFile_sendfile(const std::string &sourceFileName, const std::string &destinationFileName) {
+    int in = open(sourceFileName.c_str(), O_RDONLY);
+    if (in == -1) {
+        MMBLOG_PLAIN(WARNING, "Cannot open file " << sourceFileName << " for reading");
+
+        return CopyFileResult::Io_Error;
+    }
+
+    const auto srcSize = getFileSizeFromFd(in);
+    if (srcSize == -1) {
+        MMBLOG_PLAIN(WARNING, "Cannot determine size of the file to copy: " << strerror(errno));
+        close(in);
+
+        return CopyFileResult::Io_Error;
+    }
+
+    int out = creat(destinationFileName.c_str(), S_IWUSR | S_IRUSR);
+    if (out == -1) {
+        MMBLOG_PLAIN(WARNING, "Cannot open file " << destinationFileName << " for writing");
+	    close(in);
+
+        return CopyFileResult::Io_Error;
+    }
+
+    CopyFileResult retCode = CopyFileResult::Success;
+    auto bytesToCopy = srcSize;
+    while (bytesToCopy > 0) {
+        auto ret = sendfile(out, in, nullptr, srcSize);
+        if (ret == -1) {
+            if (errno == ENOSPC || errno == EDQUOT) {
+                retCode = CopyFileResult::No_Space;
+            } else if ((errno == EINVAL || errno == ENOSYS) && bytesToCopy == srcSize) {
+                /* Fall back to direct copying - system we are running on may not implement sendfile() the way we need.
+                 * This makes sense only if the first call to sendfile() failes, subsequent failures with the error codes
+                 * above indicate a problem somewhere else */
+                close(in);
+                close(out);
+                return mmbCopyFile_direct(sourceFileName, destinationFileName);
+            } else {
+                MMBLOG_PLAIN(WARNING, "IO error while copying a file: " << strerror(errno));
+
+                retCode = CopyFileResult::Io_Error;
+            }
+            goto out;
+        }
+
+        bytesToCopy -= ret;
+    }
+
+    if (fsync(out) == -1) {
+        if (errno == ENOSPC || errno == EDQUOT) {
+            retCode = CopyFileResult::No_Space;
+        } else {
+            MMBLOG_PLAIN(WARNING, "IO error while copying a file: " << strerror(errno));
+
+            retCode = CopyFileResult::Io_Error;
+        }
+    }
+
+out:
+    close(in);
+    close(out);
+
+    return retCode;
+}
+
+#endif // HAVE_SENDFILE
+
+inline
+std::tuple<bool, int, int, int> getLinuxKernelVersion() {
+    struct utsname kernelInfo;
+
+    if (uname(&kernelInfo) != 0) {
+        return { false, 0, 0, 0 };
+    }
+
+    if (std::strcmp(kernelInfo.sysname, "Linux") != 0) {
+        return { false, 0, 0, 0 };
+    }
+
+    std::vector<std::string> parts{};
+
+    const size_t len = strlen(kernelInfo.release);
+    size_t from = 0;
+
+    for (size_t to = 1; to < len; to++) {
+        if (kernelInfo.release[to] == '.') {
+            parts.push_back(std::string(&kernelInfo.release[from], to - from));
+            from = to + 1;
+        }
+    }
+
+    if (parts.size() < 2)
+        return { false, 0, 0, 0 };
+
+    try {
+        auto major = std::stoi(parts[0]);
+        auto minor = std::stoi(parts[1]);
+
+        if (major > 2) {
+            return { true, major, minor, 0 };
+        }
+
+        // Check for 2.6.x naming scheme
+        if (parts.size() < 3) {
+            return { false, 0, 0, 0 };
+        }
+
+        auto minorTwo = std::stoi(parts[2]);
+        return { true, major, minor, minorTwo };
+    } catch (const std::invalid_argument &) {
+        return { false, 0, 0, 0 };
+    } catch (const std::out_of_range &) {
+        return { false, 0, 0, 0 };
+    }
+}
+
+#ifdef __FreeBSD__
+
+inline
+int getFreeBSDVersion() {
+    struct utsname uts;
+
+    if (uname(&uts) != 0) {
+        return 0;
+    }
+
+    if (std::strcmp(uts.sysname, "FreeBSD") != 0) {
+        return 0;
+    }
+
+    auto delim = std::strchr(uts.release, '.');
+    if (delim == nullptr) {
+        return 0;
+    }
+
+    std::string verstr(uts.release, delim - uts.release);
+    try {
+        return std::stoi(verstr);
+    } catch (const std::invalid_argument &) {
+        return 0;
+    } catch (const std::out_of_range &) {
+        return 0;
+    }
+
+}
+
+#endif // __FreeBSD__
+
+#ifdef __FreeBSD__
+
+std::function<CopyFileResult (const std::string &, const std::string &)> getMmbCopyFileImpl() {
+    auto version = getFreeBSDVersion();
+
+#ifdef HAVE_COPY_FILE_RANGE
+    return version >= 13 ? mmbCopyFile_copy_file_range : mmbCopyFile_direct;
+#endif // HAVE_COPY_FILE_RANGE
+    return mmbCopyFile_direct;
+}
+
+#else // All other UNIXes
+
+inline
+std::function<CopyFileResult (const std::string &, const std::string &)> getMmbCopyFileImpl() {
+    auto lnxKernVer = getLinuxKernelVersion();
+
+    if (!std::get<0>(lnxKernVer)) {
+        // We are not running on Linux or cannot determine the kernel version
+        return mmbCopyFile_direct;
+    }
+
+    auto maj = std::get<1>(lnxKernVer);
+    auto min = std::get<2>(lnxKernVer);
+    auto minTwo = std::get<3>(lnxKernVer);
+
+#ifdef HAVE_COPY_FILE_RANGE
+    if (maj > 5) {
+        return mmbCopyFile_copy_file_range;
+    } else if (maj == 5 && min >= 3) {
+        return mmbCopyFile_copy_file_range;
+    }
+#endif // HAVE_COPY_FILE_RANGE
+
+#ifdef HAVE_SENDFILE
+    if (maj >= 3 || (maj == 2 && min == 6 && minTwo >= 33)) {
+        return mmbCopyFile_sendfile;
+    }
+#endif // HAVE_SENDFILE
+
+    return mmbCopyFile_direct;
+}
+
+#endif // __FreeBSD__
+
+CopyFileResult mmbCopyFile(const std::string &sourceFileName, const std::string &destinationFileName) {
+    static const std::function<CopyFileResult (const std::string &, const std::string &)> impl = getMmbCopyFileImpl();
+
+    return impl(sourceFileName, destinationFileName);
+}
+
+#endif // _WINDOWS
+
 void closingMessage() {
     std::cout<<__FILE__<<":"<<__LINE__<<std::endl;
     std::cout<<__FILE__<<":"<<__LINE__<<" Questions or problems? Please use the public forum at https://simtk.org/forums/viewforum.php?f=359&amp;sid=770b2f0d333ecb740d8c2f9e7e80e51c  .. or email me."<<std::endl;
@@ -304,7 +760,6 @@ void InterfaceContainer::addInterface(vector<String> myChains,vector<String> par
 };
 
 
-#ifdef USE_OPENMM
 vector<TwoAtomClass> InterfaceContainer::retrieveCloseContactPairs(vector<MMBAtomInfo> & concatenatedAtomInfoVector ){
 //vector<TwoAtomClass> InterfaceContainer::retrieveCloseContactPairs(  BiopolymerClassContainer & myBiopolymerClassContainer){
         OpenMM::NeighborList neighborList;
@@ -358,7 +813,6 @@ vector<TwoAtomClass> InterfaceContainer::retrieveCloseContactPairs(vector<MMBAto
         }
         return contactingAtomInfoPairVector;  
 };
-#endif
 
 ConstraintClass::ConstraintClass(){
         chain1 = ""; residueID1 = ResidueID(); atomName1 = ""; 
@@ -505,145 +959,6 @@ bool isFixed (const String putativeFixedFloat) { // This checks that the string
 	} // of for
 	return true;
 }
-/*
-// a recursive algorithm for reading a double from a String.  This String may contain ints, user variables (begin with @), +, and -.  No whitespaces or additional characters should be in the String.
-double   myAtoF(  map<const String,double> myUserVariables,  const char* value){
-    MMBLOG_FILE_FUNC_LINE(INFO, "inside myAtoF. converting string : >"<<value<<"<"<<endl);
-
-#ifdef Lepton_USAGE
-    map<string,double> leptonFormatUserVariables; // Wish this were not necessary. but userVariables uses the signature const SimTK::String,double . Lepton uses string, double.
-    leptonFormatUserVariables.clear();
-    for (auto  myUserVariablesIterator = myUserVariables.begin() ; myUserVariablesIterator !=myUserVariables.end(); myUserVariablesIterator++) {
-        leptonFormatUserVariables[myUserVariablesIterator->first] = myUserVariablesIterator->second;
-    }
-    double leptonResult = Lepton::Parser::parse(std::string(value)).evaluate(leptonFormatUserVariables);
-    MMBLOG_FILE_FUNC_LINE(INFO, " Lepton evaluation = >"<< leptonResult<<"< "<<std::endl);
-    return leptonResult; // if Lepton_USAGE is defined, then we return here and the rest of the procedure is not used. 
-#endif
-    // If Lepton_USAGE is NOT defined, then we parse the formula the old dumb way, as follows.
-
-    size_t plusPosition  = String(value).find_last_of('+'); // returns the position of the last '+' in value
-    size_t minusPosition = String(value).find_last_of('-'); // ditto for '-'
-    if ((plusPosition > minusPosition) && (plusPosition  != String::npos) )  minusPosition = String::npos; // If the plus sign is closer to the end of the string, pretend we didn't find any '-'
-    if ((plusPosition < minusPosition) && (minusPosition != String::npos) )  plusPosition  = String::npos; // Conversely, if the '-' is closer to the end, pretend we didn't find any '+' .. actually we might not have found any '+' anyway.
-    String baseDoubleString ;
-    double          increment = -1111;
-    double          decrement = -1111;
-    MMBLOG_FILE_FUNC_LINE(INFO, endl);
-    if (plusPosition != String::npos) { // We have a '+' to deal with
-        MMBLOG_FILE_FUNC_LINE(INFO, endl);
-        baseDoubleString = String(value).substr(0, (plusPosition + 0) );
-        String incrementString = (String(value).substr(plusPosition+1,1000)); // the second parameter is ridiculously large, but will be truncated at the end of the input String.
-        //MMBLOG_FILE_FUNC_LINE(" The increment String is : "<<incrementString<<endl;
-        stringstream incrementStringStream(incrementString);
-        increment = myAtoF(myUserVariables, incrementString.c_str() );
-        decrement = 0;
-        MMBLOG_FILE_FUNC_LINE(INFO, endl);
-    } else if (minusPosition != String::npos ){ // we have a '-' to deal with
-        MMBLOG_FILE_FUNC_LINE(INFO, endl);
-        if (minusPosition== 0) {
-            // If this is just a leading '-' sign, then put a zero to the left of that minus.
-            MMBLOG_FILE_FUNC_LINE(INFO, "Detected a leading \'-\' sign. Will insert a zero to the left of the \'-\'."<<endl);
-            baseDoubleString = "0.0";
-        }
-        else {
-            // Otherwise, parse whatever is to the left of the minus sign:
-            baseDoubleString = String(value).substr(0, (minusPosition + 0) ); }
-        MMBLOG_FILE_FUNC_LINE(INFO, "baseDoubleString =  >"<<baseDoubleString  <<"< "<<endl);
-
-        String decrementString = (String(value).substr(minusPosition+1,1000)); // the second parameter is ridiculously large, but will be truncated at the end of the input String.
-        stringstream decrementStringStream(decrementString);
-        MMBLOG_FILE_FUNC_LINE(INFO, "About to extract numerical decrement from the string >"<<decrementString<<"< "<<endl);
-        decrement = myAtoF(myUserVariables, decrementString.c_str() );
-        MMBLOG_FILE_FUNC_LINE(INFO, endl);
-        increment = 0;
-        //MMBLOG_FILE_FUNC_LINE(endl;
-    } else { // no + or - found. This means we can return a result without further recursion.. i.e. we are at a leaf of the recursion tree.
-        MMBLOG_FILE_FUNC_LINE(INFO, endl);
-        if (!((increment == -1111 ) && (decrement == -1111 )  )) {
-            MMBLOG_FILE_FUNC_LINE(CRITICAL, "Unexplained error!"<<endl);
-        }
-        baseDoubleString = String(value);
-        increment = 0;
-        decrement = 0;
-        double baseDouble;
-        {
-            MMBLOG_FILE_FUNC_LINE(INFO, endl);
-            if ((baseDoubleString.substr(0,1)).compare("@") ==0) {
-                MMBLOG_FILE_FUNC_LINE(INFO, endl);
-                if (myUserVariables.find(baseDoubleString.c_str()) == myUserVariables.end())
-                {
-                    MMBLOG_FILE_FUNC_LINE(CRITICAL, "Undefined user variable "<<value<<endl);
-                }
-                MMBLOG_FILE_FUNC_LINE(INFO, "Read user variable "<<baseDoubleString.c_str()<<"  which is set to : "<<myUserVariables[baseDoubleString.c_str()]<<endl);
-                baseDouble = double(myUserVariables[baseDoubleString.c_str()]);
-            }
-            else {
-                // This has no '+', '-', or leading '@'.  However it's still possible that the user gave scientific notation, so e.g. 1e-5 leads here to baseDoubleString = '1e'.  So we need to make sure there is nothing but [0-9],'+','-' in this string:
-        if (isFixed(baseDoubleString)) {
-                    baseDouble = (atof(baseDoubleString.c_str()));
-                        MMBLOG_FILE_FUNC_LINE(INFO, "We appear to be in a leaf of the recursion tree for myAtoF. Parsed >"<<baseDoubleString<< "< as : "<<baseDouble<<endl);
-        } else {
-                        MMBLOG_FILE_FUNC_LINE(CRITICAL, "There was an error processing a putative floating point number."<<endl);
-        }
-            }
-        }
-        //MMBLOG_FILE_FUNC_LINE(endl;
-        return baseDouble;
-    }
-
-    //MMBLOG_FILE_FUNC_LINE(endl;
-    double baseDouble = myAtoF(myUserVariables,baseDoubleString.c_str() ) ;
-
-    double finalDouble = baseDouble + increment - decrement;
-    MMBLOG_FILE_FUNC_LINE(INFO, "Result of >"<< value  <<"< is : " << finalDouble <<endl);
-    return finalDouble;
-}*/
-/*
-bool aToBool(  const char* value ) {
-
-    String upperValue(value);
-    for(int i=0;i<(int)upperValue.length();i++)  {
-        upperValue[i] = toupper(value[i]);
-    }
-
-    if (( upperValue ==  "TRUE" ) ||( upperValue ==  "1")) {
-        MMBLOG_FILE_FUNC_LINE(DEBUG, "TRUE"<<endl);
-        return true;
-    }
-    else if (( upperValue ==  "FALSE" ) ||( upperValue ==  "0")){
-        MMBLOG_FILE_FUNC_LINE(DEBUG, "FALSE"<<endl);
-        return false;
-    }
-    else {
-        MMBLOG_FILE_FUNC_LINE(INFO, "Error -- you have specified"<<value<<endl);
-        SimTK_ERRCHK_ALWAYS((upperValue == "TRUE" || upperValue == "FALSE" || upperValue == "1"  || upperValue == "0") ,"[ParameterReader.cpp]"," requires either True or False but was set to something else");
-        return false;
-    }
-
-}
-bool aToBool( const String& name, const char* value ) {
-    return aToBool(value);
-}
-bool compareUpper( const String& param, const char* symbol ) {
-
-    String upperParam(param);
-    String upperSym(symbol);
-
-    if( upperParam.length() != upperSym.length() ) return false;
-
-
-    for(int i=0;i<(int)upperParam.length();i++)  {
-        upperParam[i] = toupper(param[i]);
-        upperSym[i] = toupper(symbol[i]);
-    }
-
-    if( upperParam ==  upperSym )
-        return true;
-    else
-        return false;
-}
-*/
 
 
     // a recursive algorithm for reading an integer from a String.  This String may contain ints, user variables (begin with @), +, and -.  No whitespaces or additional characters should be in the String.
@@ -885,12 +1200,12 @@ vector<String> readAndParseOnColWidth   (ifstream & inFile, int columnWidth) {
         };  
     };  
     void ParameterStringClass::print() const {
-        MMBLOG_FILE_FUNC_LINE(DEBUG, endl);
+        MMBLOG_FILE_FUNC_LINE(DEBUG," About to print the contents of ParameterStringClass, which is in charge of storing and processing a single line from the user command file."<< endl);
         for (int i = 0 ; i < size(); i++){
             MMBLOG_FILE_FUNC_LINE(DEBUG, stringVector[i]<<" ");
             //std::cout<<__FILE__<<":"<<__LINE__<<" "<<i<<" >"<<stringVector[i]<<"< "<<std::endl;
         };
-        MMBLOG_FILE_FUNC_LINE(INFO, endl);
+        //#MMBLOG_FILE_FUNC_LINE(INFO, endl);
     };
 
     String ParameterStringClass::getString() const {
